@@ -258,8 +258,9 @@ void EditPage::onServiceRegistered(const QString& service)
         watcher->deleteLater();
     });
 
-    if (!m_errorOverlay.isNull()) {
-        m_errorOverlay.data()->deleteLater();
+    if (m_errorOverlay) {
+        m_errorOverlay->deleteLater();
+        m_errorOverlay = nullptr;
     }
 }
 
@@ -267,8 +268,8 @@ void EditPage::onServiceUnregistered(const QString& service)
 {
     Q_UNUSED(service);
 
-    if (!m_errorOverlay.isNull()) {
-        m_errorOverlay.data()->deleteLater();
+    if (m_errorOverlay) {
+        m_errorOverlay->deleteLater();
     }
 
     m_errorOverlay = new ErrorOverlay(this, i18n("The Power Management Service appears not to be running.\n"
